==> haskell-servant-swagger-1.1.4-64-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-swagger
version: 1.1.4
id: servant-swagger-1.1.4-5GpmTs4vIukEidQlKEMf91
key: servant-swagger-1.1.4-5GpmTs4vIukEidQlKEMf91
license: BSD3
copyright: (c) 2015-2016, Servant contributors
maintainer: nickolay.kudasov@gmail.com
homepage: https://github.com/haskell-servant/servant-swagger
synopsis: Generate Swagger specification for your servant API.
description:
    Please see README.md
category: Web, Servant, Swagger
author: David Johnson, Nickolay Kudasov
exposed: True
indefinite: False
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Test Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel
abi: d38f377b3bea45243e82eaff6f7981c3
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/servant-swagger-1.1.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/servant-swagger-1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/servant-swagger-1.1.4
hs-libraries: HSservant-swagger-1.1.4-5GpmTs4vIukEidQlKEMf91
depends:
    aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF base-4.10.1.0
    bytestring-0.10.8.2 http-media-0.7.1.2-2XGhz66IUTJL2DIjDR0MW
    insert-ordered-containers-0.2.1.0-Il2HgB4vBRbAtnw3pXokAt
    lens-4.15.4-CcieSmu1RSJLB2Tu4Je8zo
    servant-0.12.1-1ZGSPBMzzKvERRVtcbIImR
    swagger2-2.2.1-AJ2ccFnx9my2dhUOAU86s6
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    hspec-2.5.0-JMQMLcXJNVV8FfCg6qrSWm
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9
abi-depends: aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF=117e2ccb320a02562b7dab8dac8cab03
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             http-media-0.7.1.2-2XGhz66IUTJL2DIjDR0MW=1f559118d6e10a91a8840f65cacc3846
             insert-ordered-containers-0.2.1.0-Il2HgB4vBRbAtnw3pXokAt=19506002fc16bdc00caa2c1a0f2abeec
             lens-4.15.4-CcieSmu1RSJLB2Tu4Je8zo=debbb5c6e3ce2aad169db2abcbc3ef09
             servant-0.12.1-1ZGSPBMzzKvERRVtcbIImR=5dc103974d3f56cf831a5db9e8819ec8
             swagger2-2.2.1-AJ2ccFnx9my2dhUOAU86s6=be7e7805b46560b2bac29c64310e4ab8
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             hspec-2.5.0-JMQMLcXJNVV8FfCg6qrSWm=cb7d498ce7553680e59773d86168e04d
             QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
haddock-interfaces: /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock
haddock-html: /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-swagger-1.1.4-65-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-swagger
version: 1.1.4
id: servant-swagger-1.1.4-H7Bbi0H1p5s5nB3mqLwt5s
key: servant-swagger-1.1.4-H7Bbi0H1p5s5nB3mqLwt5s
license: BSD3
copyright: (c) 2015-2016, Servant contributors
maintainer: nickolay.kudasov@gmail.com
homepage: https://github.com/haskell-servant/servant-swagger
synopsis: Generate Swagger specification for your servant API.
description:
    Please see README.md
category: Web, Servant, Swagger
author: David Johnson, Nickolay Kudasov
exposed: True
indefinite: False
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Test Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel
abi: 5b8745104ffc94eb0c773bc7c1614379
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/servant-swagger-1.1.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/servant-swagger-1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/servant-swagger-1.1.4
hs-libraries: HSservant-swagger-1.1.4-H7Bbi0H1p5s5nB3mqLwt5s
depends:
    aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF base-4.10.1.0
    bytestring-0.10.8.2 http-media-0.7.1.2-2XGhz66IUTJL2DIjDR0MW
    insert-ordered-containers-0.2.1.0-Lt6NCOuhr7tJDzE7UTkL67
    lens-4.15.4-6m0DRudBlbcIMz3JMQWt18
    servant-0.12.1-1ZGSPBMzzKvERRVtcbIImR
    swagger2-2.2.1-6GoGrCNABKU7WZrmipDgdt
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    hspec-2.5.0-JMQMLcXJNVV8FfCg6qrSWm
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9
abi-depends: aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF=117e2ccb320a02562b7dab8dac8cab03
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             http-media-0.7.1.2-2XGhz66IUTJL2DIjDR0MW=1f559118d6e10a91a8840f65cacc3846
             insert-ordered-containers-0.2.1.0-Lt6NCOuhr7tJDzE7UTkL67=39e5ad23ee295ae22b5559db5935d943
             lens-4.15.4-6m0DRudBlbcIMz3JMQWt18=711291bbead8ac7054491886b474b5a2
             servant-0.12.1-1ZGSPBMzzKvERRVtcbIImR=5dc103974d3f56cf831a5db9e8819ec8
             swagger2-2.2.1-6GoGrCNABKU7WZrmipDgdt=517a6be4f3dd786abdb3f3d455507613
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             hspec-2.5.0-JMQMLcXJNVV8FfCg6qrSWm=cb7d498ce7553680e59773d86168e04d
             QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
haddock-interfaces: /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock
haddock-html: /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
